@@ -5,10 +5,9 @@
 #  addOBV
 
 `addOBV` <-
-function (..., on = NA, legend = "auto") 
+function (..., on = NA, legend = "auto")
 {
-    stopifnot("package:TTR" %in% search() || require("TTR", quietly = TRUE))
-    lchob <- quantmod:::get.current.chob()
+    lchob <- get.current.chob()
     x <- as.matrix(lchob@xdata)
     x <- OBV(price = Cl(x), volume = Vo(x))
     yrange <- NULL
@@ -26,22 +25,21 @@ function (..., on = NA, legend = "auto")
         chobTA@on <- on
     }
     chobTA@call <- match.call()
-    legend.name <- gsub("^.*[(]", " On Balance Volume (", deparse(match.call()))#, 
+    legend.name <- gsub("^.*[(]", " On Balance Volume (", deparse(match.call()))#,
         #extended = TRUE)
     gpars <- c(list(...), list(col=4))[unique(names(c(list(col=4), list(...))))]
-    chobTA@params <- list(xrange = lchob@xrange, yrange = yrange, 
-        colors = lchob@colors, color.vol = lchob@color.vol, multi.col = lchob@multi.col, 
-        spacing = lchob@spacing, width = lchob@width, bp = lchob@bp, 
-        x.labels = lchob@x.labels, time.scale = lchob@time.scale, 
-        isLogical = is.logical(x), legend = legend, legend.name = legend.name, 
+    chobTA@params <- list(xrange = lchob@xrange, yrange = yrange,
+        colors = lchob@colors, color.vol = lchob@color.vol, multi.col = lchob@multi.col,
+        spacing = lchob@spacing, width = lchob@width, bp = lchob@bp,
+        x.labels = lchob@x.labels, time.scale = lchob@time.scale,
+        isLogical = is.logical(x), legend = legend, legend.name = legend.name,
         pars = list(gpars))
     if (is.null(sys.call(-1))) {
         TA <- lchob@passed.args$TA
         lchob@passed.args$TA <- c(TA, chobTA)
-        lchob@windows <- lchob@windows + ifelse(chobTA@new, 1, 
+        lchob@windows <- lchob@windows + ifelse(chobTA@new, 1,
             0)
-        chartSeries.chob <- quantmod:::chartSeries.chob
-        do.call("chartSeries.chob", list(lchob))
+        do.call(chartSeries.chob, list(lchob))
         invisible(chobTA)
     }
     else {
