@@ -23,8 +23,6 @@ function(Symbols=NULL,
                 'options("getSymbols.warning4.0"=FALSE). See ?getSymbol for more details'))
         options("getSymbols.warning4.0"=FALSE)
       }
-      if(requireNamespace('Defaults'))
-          Defaults::importDefaults("getSymbols")
       #  to enable as-it-was behavior, set this:
       #  options(getSymbols=list(env=substitute(parent.frame(3))))
 
@@ -124,7 +122,6 @@ formals(loadSymbols) <- loadSymbols.formals
 #                              bb.suffix="Equity",
 #                              bb.interval="5",
 #                              ...) {
-#    importDefaults("getSymbols.Bloomberg")
 #    this.env <- environment()
 #    for(var in names(list(...))) {
 #       # import all named elements that are NON formals
@@ -220,8 +217,6 @@ function(Symbols,env,return.class='xts',index.class="Date",
          to=Sys.Date(),
          ...)
 {
-     if(requireNamespace('Defaults'))
-         Defaults::importDefaults("getSymbols.yahoo")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -317,8 +312,6 @@ function(Symbols,env,return.class='xts',
          ...)
 {
      fix.google.bug <- TRUE
-     if(requireNamespace('Defaults'))
-         Defaults::importDefaults("getSymbols.google")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -388,8 +381,6 @@ function(Symbols,env,return.class='xts',
                                dbname=NULL,
                                POSIX = TRUE,
                                ...) {
-     if(requireNamespace('Defaults'))
-         Defaults::importDefaults("getSymbols.SQLite")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -453,8 +444,6 @@ function(Symbols,env,return.class='xts',
                                field.names = NULL,
                                user=NULL,password=NULL,dbname=NULL,host='localhost',port=3306,
                                ...) {
-     if(requireNamespace('Defaults'))
-         Defaults::importDefaults("getSymbols.MySQL")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -511,8 +500,6 @@ function(Symbols,env,return.class='xts',
 # getSymbols.FRED {{{
 `getSymbols.FRED` <- function(Symbols,env,
      return.class="xts", ...) {
-     if(requireNamespace('Defaults'))
-         Defaults::importDefaults("getSymbols.FRED")
      this.env <- environment()
      for(var in names(list(...))) {
         # import all named elements that are NON formals
@@ -555,8 +542,6 @@ function(Currencies,from=Sys.Date()-499,to=Sys.Date(),
          env=parent.frame(),
          verbose=FALSE,warning=TRUE,
          auto.assign=TRUE,...) {
-  if(requireNamespace('Defaults'))
-        Defaults::importDefaults("getFX")
   if(missing(env))
     env <- parent.frame(1)
   if(is.null(env))
@@ -586,8 +571,6 @@ function(Metals,from=Sys.Date()-500,to=Sys.Date(),
          base.currency="USD",env=parent.frame(),
          verbose=FALSE,warning=TRUE,
          auto.assign=TRUE,...) {
-  if(requireNamespace('Defaults'))
-    Defaults::importDefaults("getMetals")
   if(missing(env))
     env <- parent.frame(1)
   if(is.null(env))
@@ -617,8 +600,6 @@ function(Symbols,env,
          return.class="xts",
          extension="csv",
          ...) {
-  if(requireNamespace('Defaults'))
-    Defaults::importDefaults("getSymbols.csv")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -686,8 +667,6 @@ function(Symbols,env,
          extension="rds",
          col.names=c('Open','High','Low','Close','Volume','Adjusted'),
          ...) {
-  if(requireNamespace('Defaults'))
-    Defaults::importDefaults("getSymbols.rds")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -746,8 +725,6 @@ function(Symbols,env,
          extension="rda",
          col.names=c('Open','High','Low','Close','Volume','Adjusted'),
          ...) {
-  if(requireNamespace('Defaults'))
-    Defaults::importDefaults("getSymbols.rda")
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var,list(...)[[var]], this.env)
@@ -808,8 +785,6 @@ function(Symbols,env,
 endDateTime, barSize='1 day', duration='1 M',
 useRTH = '1', whatToShow = 'TRADES', time.format = '1', ...)
 {
-  if(requireNamespace('Defaults'))
-    Defaults::importDefaults('getSymbols.IBrokers')
   this.env <- environment()
   for(var in names(list(...))) {
     assign(var, list(...)[[var]], this.env)
@@ -883,8 +858,6 @@ function(Symbols,env,return.class='xts',
          from=Sys.Date()-499,
          to=Sys.Date(),
          ...) {
-     if(requireNamespace('Defaults'))
-       Defaults::importDefaults("getSymbols.oanda")
      if( (as.Date(to)-as.Date(from)) > 500 )
        stop("oanda.com limits data to 500 days per request", call.=FALSE)
      this.env <- environment()
