@@ -2,7 +2,7 @@ findPeaks <-
 function(x, thresh=0) {
   pks <- which(diff(sign(diff(x, na.pad=FALSE)),na.pad=FALSE) < 0) + 2
   if( !missing(thresh) ) {
-   pks[x[pks-1]-x[pks] > thresh]
+   pks[x[pks-1]-coredata(x[pks]) > thresh]
   } else pks
 }
 
@@ -15,7 +15,7 @@ findValleys <-
 function(x, thresh=0) {
   pks <- which(diff(sign(diff(x, na.pad=FALSE)),na.pad=FALSE) > 0) + 2
   if( !missing(thresh) ) {
-   pks[x[pks-1]-x[pks] > thresh]
+   pks[x[pks-1]-coredata(x[pks]) > thresh]
   } else pks
 }
 
